@@ -8,13 +8,19 @@ version <- packageDescription("mvtnorm")$Version
 
 
 ###################################################
-### code chunk number 2: chk
+### code chunk number 2: digits
+###################################################
+options(digits = 4)
+
+
+###################################################
+### code chunk number 3: chk
 ###################################################
 chk <- function(...) stopifnot(isTRUE(all.equal(...)))
 
 
 ###################################################
-### code chunk number 3: example
+### code chunk number 4: example
 ###################################################
 library("mvtnorm")
 set.seed(290875)
@@ -41,7 +47,7 @@ lxn
 
 
 ###################################################
-### code chunk number 4: ex-reorder
+### code chunk number 5: ex-reorder
 ###################################################
 ## constructor + .reorder + as.array
 a <- as.array(ltMatrices(xn, byrow = TRUE))
@@ -66,7 +72,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 5: ex-subset (eval = FALSE)
+### code chunk number 6: ex-subset (eval = FALSE)
 ###################################################
 ## ## subset
 ## a <- as.array(ltMatrices(xn, byrow = FALSE, names = nm)[i, j])
@@ -91,7 +97,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 6: ex-subset-1
+### code chunk number 7: ex-subset-1
 ###################################################
 i <- colnames(xn)[1:2]
 j <- 2:4
@@ -118,7 +124,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 7: ex-subset-2
+### code chunk number 8: ex-subset-2
 ###################################################
 i <- 1:2
 j <- nm[2:4]
@@ -145,7 +151,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 8: ex-subset-3
+### code chunk number 9: ex-subset-3
 ###################################################
 j <- c(1, 3, 5)
 ## subset
@@ -171,7 +177,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 9: ex-subset-4
+### code chunk number 10: ex-subset-4
 ###################################################
 j <- nm[c(1, 3, 5)]
 ## subset
@@ -197,7 +203,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 10: ex-subset-5
+### code chunk number 11: ex-subset-5
 ###################################################
 j <- -c(1, 3, 5)
 ## subset
@@ -223,7 +229,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 11: ex-subset-6
+### code chunk number 12: ex-subset-6
 ###################################################
 ## subset
 j <- nm[sample(1:J)]
@@ -236,7 +242,7 @@ chk(a, b)
 
 
 ###################################################
-### code chunk number 12: ex-Lower_tri
+### code chunk number 13: ex-Lower_tri
 ###################################################
 ## J <- 4
 M <- ltMatrices(matrix(1:10, nrow = 10, ncol = 2), diag = TRUE)
@@ -250,13 +256,13 @@ Lower_tri(invchol2cor(M))
 
 
 ###################################################
-### code chunk number 13: ex-diag
+### code chunk number 14: ex-diag
 ###################################################
 all(diagonals(ltMatrices(xn, byrow = TRUE)) == 1L)
 
 
 ###################################################
-### code chunk number 14: ex-addiag
+### code chunk number 15: ex-addiag
 ###################################################
 lxd2 <- lxn
 diagonals(lxd2) <- 1
@@ -264,7 +270,7 @@ chk(as.array(lxd2), as.array(lxn))
 
 
 ###################################################
-### code chunk number 15: ex-diagJ
+### code chunk number 16: ex-diagJ
 ###################################################
 (I5 <- diagonals(5L))
 diagonals(I5) <- 1:5
@@ -272,7 +278,7 @@ I5
 
 
 ###################################################
-### code chunk number 16: ex-mult
+### code chunk number 17: ex-mult
 ###################################################
 lxn <- ltMatrices(xn, byrow = TRUE)
 lxd <- ltMatrices(xd, byrow = TRUE, diag = TRUE)
@@ -305,7 +311,7 @@ chk(a, b, check.attributes = FALSE)
 
 
 ###################################################
-### code chunk number 17: ex-tmult
+### code chunk number 18: ex-tmult
 ###################################################
 a <- Mult(lxn, y, transpose = TRUE)
 A <- as.array(lxn)
@@ -329,7 +335,7 @@ chk(Mult(lxn, y[,1], transpose = TRUE),
 
 
 ###################################################
-### code chunk number 18: ex-symult
+### code chunk number 19: ex-symult
 ###################################################
 J <- 5
 N1 <- 10
@@ -360,7 +366,7 @@ eval(ex)
 
 
 ###################################################
-### code chunk number 19: ex-solve
+### code chunk number 20: ex-solve
 ###################################################
 ## solve
 A <- as.array(lxn)
@@ -388,14 +394,14 @@ chk(solve(lxn, y[,1]), solve(lxn, y[,rep(1, N)]))
 
 
 ###################################################
-### code chunk number 20: ex-tsolve
+### code chunk number 21: ex-tsolve
 ###################################################
 chk(solve(lxn[1,], y, transpose = TRUE), 
     t(as.array(solve(lxn[1,]))[,,1]) %*% y)
 
 
 ###################################################
-### code chunk number 21: ex-logdet
+### code chunk number 22: ex-logdet
 ###################################################
 chk(logdet(lxn), colSums(log(diagonals(lxn))))
 chk(logdet(lxd[1,]), colSums(log(diagonals(lxd[1,]))))
@@ -405,7 +411,7 @@ chk(logdet(lxd2), colSums(log(diagonals(lxd2))))
 
 
 ###################################################
-### code chunk number 22: ex-tcrossprod
+### code chunk number 23: ex-tcrossprod
 ###################################################
 ## Tcrossprod
 a <- as.array(Tcrossprod(lxn))
@@ -430,7 +436,7 @@ chk(d, diagonals(Tcrossprod(lxd)))
 
 
 ###################################################
-### code chunk number 23: ex-crossprod
+### code chunk number 24: ex-crossprod
 ###################################################
 ## Crossprod
 a <- as.array(Crossprod(lxn))
@@ -455,7 +461,7 @@ chk(d, diagonals(Crossprod(lxd)))
 
 
 ###################################################
-### code chunk number 24: chol
+### code chunk number 25: chol
 ###################################################
 Sigma <- Tcrossprod(lxd)
 chk(chol(Sigma), lxd)
@@ -465,7 +471,7 @@ chk(as.array(chol(Sigma)), as.array(lxn))
 
 
 ###################################################
-### code chunk number 25: kronecker
+### code chunk number 26: kronecker
 ###################################################
 J <- 10
 
@@ -521,7 +527,7 @@ chk(A, B)
 
 
 ###################################################
-### code chunk number 26: conv-ex-1
+### code chunk number 27: conv-ex-1
 ###################################################
 prec2pc <- function(x) {
     ret <- -cov2cor(x)
@@ -548,7 +554,7 @@ chk(unlist(PC), c(as.array(invchol2pc(L))),
 
 
 ###################################################
-### code chunk number 27: conv-ex-2
+### code chunk number 28: conv-ex-2
 ###################################################
 C <- lxn
 Sigma <- apply(as.array(C), 3, 
@@ -570,7 +576,7 @@ chk(unlist(PC), c(as.array(chol2pc(C))),
 
 
 ###################################################
-### code chunk number 28: conv-ex-3
+### code chunk number 29: conv-ex-3
 ###################################################
 L <- lxd
 Sigma <- apply(as.array(L), 3, 
@@ -592,7 +598,7 @@ chk(unlist(PC), c(as.array(invchol2pc(L))),
 
 
 ###################################################
-### code chunk number 29: conv-ex-4
+### code chunk number 30: conv-ex-4
 ###################################################
 C <- lxd
 Sigma <- apply(as.array(C), 3, 
@@ -614,7 +620,7 @@ chk(unlist(PC), c(as.array(chol2pc(C))),
 
 
 ###################################################
-### code chunk number 30: aperm-tests
+### code chunk number 31: aperm-tests
 ###################################################
 L <- as.invchol(lxn)
 J <- dim(L)[2L]
@@ -628,7 +634,7 @@ chk(chol2cov(C)[,p], chol2cov(Cp))
 
 
 ###################################################
-### code chunk number 31: marg
+### code chunk number 32: marg
 ###################################################
 Sigma <- Tcrossprod(lxd)
 j <- 1:3
@@ -644,7 +650,7 @@ chk(Sigma[,j], Tcrossprod(solve(marg_mvnorm(invchol = lxd, which = j)$invchol)))
 
 
 ###################################################
-### code chunk number 32: cond-general
+### code chunk number 33: cond-general
 ###################################################
 Sigma <- as.array(Tcrossprod(lxd))[,,1]
 j <- 2:4
@@ -674,7 +680,7 @@ chk(cS, as.array(Tcrossprod(solve(cmv$invchol)))[,,1])
 
 
 ###################################################
-### code chunk number 33: cond-simple
+### code chunk number 34: cond-simple
 ###################################################
 Sigma <- as.array(Tcrossprod(lxd))[,,1]
 j <- 1:3
@@ -704,7 +710,7 @@ chk(cS, as.array(Tcrossprod(solve(cmv$invchol)))[,,1])
 
 
 ###################################################
-### code chunk number 34: ex-MV
+### code chunk number 35: ex-MV
 ###################################################
 N <- 1000L
 J <- 50L
@@ -721,14 +727,14 @@ chk(ll1, ll2)
 
 
 ###################################################
-### code chunk number 35: ex-MV-d
+### code chunk number 36: ex-MV-d
 ###################################################
 ll3 <- ldmvnorm(obs = Y, invchol = lt)
 chk(ll1, ll3)
 
 
 ###################################################
-### code chunk number 36: ex-MV-mc
+### code chunk number 37: ex-MV-mc
 ###################################################
 ## marginal of and conditional on these
 (j <- 1:5 * 10)
@@ -743,13 +749,13 @@ chk(ll1, ll3)
 
 
 ###################################################
-### code chunk number 37: chapterseed
+### code chunk number 38: chapterseed
 ###################################################
 set.seed(270312)
 
 
 ###################################################
-### code chunk number 38: fct-lpmvnormR
+### code chunk number 39: fct-lpmvnormR
 ###################################################
 
 lpmvnormR <- function(lower, upper, mean = 0, center = NULL, chol, logLik = TRUE, ...) {
@@ -806,7 +812,7 @@ lpmvnormR <- function(lower, upper, mean = 0, center = NULL, chol, logLik = TRUE
 
 
 ###################################################
-### code chunk number 39: ex-lpmvnorm_R
+### code chunk number 40: ex-lpmvnorm_R
 ###################################################
 J <- 5L
 N <- 10L
@@ -823,7 +829,7 @@ b[sample(J * N)[1:2]] <- Inf
 
 
 ###################################################
-### code chunk number 40: ex-again
+### code chunk number 41: ex-again
 ###################################################
 phat
 exp(lpmvnorm(a, b, chol = lx, M = 25000, logLik = FALSE, fast = TRUE))
@@ -831,7 +837,7 @@ exp(lpmvnorm(a, b, chol = lx, M = 25000, logLik = FALSE, fast = FALSE))
 
 
 ###################################################
-### code chunk number 41: ex-lpmvnorm
+### code chunk number 42: ex-lpmvnorm
 ###################################################
 M <- 10000L
 if (require("qrng", quietly = TRUE)) {
@@ -862,7 +868,7 @@ cbind(pGB, pGqf, pGf, pGqs, pGs)
 
 
 ###################################################
-### code chunk number 42: ex-uni
+### code chunk number 43: ex-uni
 ###################################################
 ### test univariate problem
 ### call pmvnorm
@@ -879,7 +885,7 @@ cbind(c(ptr), pGB, pGq)
 
 
 ###################################################
-### code chunk number 43: ex-score
+### code chunk number 44: ex-score
 ###################################################
 J <- 5L
 N <- 4L
@@ -915,7 +921,7 @@ if (require("numDeriv", quietly = TRUE))
 
 
 ###################################################
-### code chunk number 44: ex-Lscore
+### code chunk number 45: ex-Lscore
 ###################################################
 mL <- solve(mC)
 
@@ -938,7 +944,7 @@ if (require("numDeriv", quietly = TRUE))
 
 
 ###################################################
-### code chunk number 45: ex-uni-score
+### code chunk number 46: ex-uni-score
 ###################################################
 ptr <- pnorm(b[1,] / c(unclass(mC[,1]))) - pnorm(a[1,] / c(unclass(mC[,1])))
 log(ptr)
@@ -950,26 +956,25 @@ sd1 <- c(unclass(mC[,1]))
 
 
 ###################################################
-### code chunk number 46: chapterseed
+### code chunk number 47: chapterseed
 ###################################################
 set.seed(110515)
 
 
 ###################################################
-### code chunk number 47: ex-ML-dgp
+### code chunk number 48: ex-ML-dgp
 ###################################################
 J <- 4
 R <- diag(J)
 R[1,2] <- R[2,1] <- .25
 R[1,3] <- R[3,1] <- .5
 R[2,4] <- R[4,2] <- .75
-### ATLAS and M1mac print 0 as something < .Machine$double.eps
-round(Sigma <- diag(sqrt(1:J / 2)) %*% R %*% diag(sqrt(1:J / 2)), 7)
-(C <- t(chol(Sigma)))
+Sigma <- diag(sqrt(1:J / 2)) %*% R %*% diag(sqrt(1:J / 2))
+C <- t(chol(Sigma))
 
 
 ###################################################
-### code chunk number 48: ex-ML-C
+### code chunk number 49: ex-ML-C
 ###################################################
 prm <- C[lower.tri(C, diag = TRUE)]
 lt <- ltMatrices(matrix(prm, ncol = 1L), 
@@ -983,7 +988,7 @@ chk(Sigma, as.array(Tcrossprod(lt))[,,1], check.attributes = FALSE)
 
 
 ###################################################
-### code chunk number 49: ex-ML-data
+### code chunk number 50: ex-ML-data
 ###################################################
 N <- 100L
 Z <- matrix(rnorm(N * J), nrow = J)
@@ -991,14 +996,14 @@ Y <- Mult(lt, Z) + (mn <- 1:J)
 
 
 ###################################################
-### code chunk number 50: ex-ML-mu-vcov
+### code chunk number 51: ex-ML-mu-vcov
 ###################################################
 rowMeans(Y)
 (Shat <- var(t(Y)) * (N - 1) / N)
 
 
 ###################################################
-### code chunk number 51: ex-ML-clogLik
+### code chunk number 52: ex-ML-clogLik
 ###################################################
 Yc <- Y - rowMeans(Y)
 
@@ -1014,14 +1019,14 @@ sc <- function(parm) {
 
 
 ###################################################
-### code chunk number 52: ex-ML-const
+### code chunk number 53: ex-ML-const
 ###################################################
 llim <- rep(-Inf, J * (J + 1) / 2)
 llim[which(rownames(unclass(lt)) %in% paste(1:J, 1:J, sep = "."))] <- 1e-4
 
 
 ###################################################
-### code chunk number 53: ex-ML-c
+### code chunk number 54: ex-ML-c
 ###################################################
 if (BYROW) {
   cML <- chol(Shat)[upper.tri(Shat, diag = TRUE)]
@@ -1035,10 +1040,10 @@ if (require("numDeriv", quietly = TRUE))
 
 
 ###################################################
-### code chunk number 54: ex-ML-coptim
+### code chunk number 55: ex-ML-coptim
 ###################################################
 op <- optim(start, fn = ll, gr = sc, method = "L-BFGS-B", 
-            lower = llim, control = list(trace = TRUE))
+            lower = llim, control = list(trace = FALSE))
 ## ML numerically
 ltMatrices(op$par, diag = TRUE, byrow = BYROW)
 ll(op$par)
@@ -1050,7 +1055,7 @@ lt
 
 
 ###################################################
-### code chunk number 55: ex-ML-cens
+### code chunk number 56: ex-ML-cens
 ###################################################
 prb <- 1:9 / 10
 sds <- sqrt(diag(Sigma))
@@ -1064,7 +1069,7 @@ for (j in 1:J) {
 
 
 ###################################################
-### code chunk number 56: ex-ML-chk (eval = FALSE)
+### code chunk number 57: ex-ML-chk (eval = FALSE)
 ###################################################
 ## M <- floor(exp(0:25/10) * 1000)
 ## lGB <- sapply(M, function(m) {
@@ -1092,7 +1097,7 @@ for (j in 1:J) {
 
 
 ###################################################
-### code chunk number 57: ex-ML-fig-data
+### code chunk number 58: ex-ML-fig-data
 ###################################################
 ### use pre-computed data, otherwise CRAN complains.
 M <-
@@ -1129,7 +1134,7 @@ rownames(lHf) <- c("user.self", "ll")
 
 
 ###################################################
-### code chunk number 58: ex-ML-fig
+### code chunk number 59: ex-ML-fig
 ###################################################
 layout(matrix(1:2, nrow = 1))
 plot(M, lGB["ll",], ylim = range(c(lGB["ll",], lH["ll",], lHf["ll",])), ylab = "Log-likelihood")
@@ -1142,7 +1147,7 @@ legend("bottomright", legend = c("pmvnorm", "lpmvnorm", "lpmvnorm(fast)"), pch =
 
 
 ###################################################
-### code chunk number 59: ex-ML-ll
+### code chunk number 60: ex-ML-ll
 ###################################################
 M <- 500 
 if (require("qrng", quietly = TRUE)) {
@@ -1163,7 +1168,7 @@ ll <- function(parm, J) {
 
 
 ###################################################
-### code chunk number 60: ex-ML-check
+### code chunk number 61: ex-ML-check
 ###################################################
 prm <- c(mn, unclass(lt))
 ll(prm, J = J)
@@ -1176,7 +1181,7 @@ chk(llprm, sum(lpmvnorm(lwr, upr, mean = mn, chol = lt, w = W,
 
 
 ###################################################
-### code chunk number 61: ex-ML-sc
+### code chunk number 62: ex-ML-sc
 ###################################################
 sc <- function(parm, J) {
     m <- parm[1:J]             ### mean parameters
@@ -1190,14 +1195,14 @@ sc <- function(parm, J) {
 
 
 ###################################################
-### code chunk number 62: ex-ML-sc-chk
+### code chunk number 63: ex-ML-sc-chk
 ###################################################
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll, prm, J = J), sc(prm, J = J), check.attributes = FALSE)
 
 
 ###################################################
-### code chunk number 63: ex-ML
+### code chunk number 64: ex-ML
 ###################################################
 llim <- rep(-Inf, J + J * (J + 1) / 2)
 llim[J + which(rownames(unclass(lt)) %in% paste(1:J, 1:J, sep = "."))] <- 1e-4
@@ -1211,14 +1216,14 @@ if (BYROW) {
 ll(start, J = J)
 
 op <- optim(start, fn = ll, gr = sc, J = J, method = "L-BFGS-B", 
-            lower = llim, control = list(trace = TRUE))
+            lower = llim, control = list(trace = FALSE))
 
 op$value ## compare with 
 ll(prm, J = J)
 
 
 ###################################################
-### code chunk number 64: ex-ML-C
+### code chunk number 65: ex-ML-C
 ###################################################
 (C <- ltMatrices(matrix(op$par[-(1:J)], ncol = 1), 
                  diag = TRUE, byrow = BYROW))
@@ -1226,43 +1231,43 @@ lt
 
 
 ###################################################
-### code chunk number 65: ex-ML-mu
+### code chunk number 66: ex-ML-mu
 ###################################################
 op$par[1:J]
 mn
 
 
 ###################################################
-### code chunk number 66: ex-ML-Shat
+### code chunk number 67: ex-ML-Shat
 ###################################################
 ### ATLAS print issues
-round(Tcrossprod(lt), 7)  ### true Sigma
-round(Tcrossprod(C), 7)   ### interval-censored obs
-round(Shat, 7)            ### "exact" obs
+round(Tcrossprod(lt), 4)  ### true Sigma
+Tcrossprod(C)             ### interval-censored obs
+Shat                      ### "exact" obs
 
 
 ###################################################
-### code chunk number 67: regressions
+### code chunk number 68: regressions
 ###################################################
 c(cond_mvnorm(chol = C, which = 2:J, given = diag(J - 1))$mean)
 
 
 ###################################################
-### code chunk number 68: regressionsC
+### code chunk number 69: regressionsC
 ###################################################
 c(cond_mvnorm(chol = aperm(as.chol(C), perm = c(2:J, 1)),
               which = 1:(J - 1), given = diag(J - 1))$mean)
 
 
 ###################################################
-### code chunk number 69: regressionsP
+### code chunk number 70: regressionsP
 ###################################################
 x <- as.array(chol2pre(aperm(as.chol(C), perm = c(2:J, 1))))[J,,1]
 c(-x[-J] / x[J])
 
 
 ###################################################
-### code chunk number 70: lm-ex
+### code chunk number 71: lm-ex
 ###################################################
 dY <- as.data.frame(t(Y))
 colnames(dY) <- paste0("Y", 1:J)
@@ -1270,14 +1275,15 @@ coef(m1 <- lm(Y1 ~ ., data = dY))[-1L]
 
 
 ###################################################
-### code chunk number 71: hessian
+### code chunk number 72: hessian
 ###################################################
 H <- optim(op$par, fn = ll, gr = sc, J = J, method = "L-BFGS-B", 
-           lower = llim, hessian = TRUE)$hessian
+           lower = llim, hessian = TRUE, 
+           control = list(trace = FALSE))$hessian
 
 
 ###################################################
-### code chunk number 72: ML-sample
+### code chunk number 73: ML-sample
 ###################################################
 L <- try(t(chol(H)))
 ### some check on r-oldrel-macos-arm64
@@ -1290,33 +1296,33 @@ rC <- solve(L, Z)[-(1:J),] + op$par[-(1:J)] ### remove mean parameters
 
 
 ###################################################
-### code chunk number 73: ML-check
+### code chunk number 74: ML-check
 ###################################################
 c(sqrt(rowMeans((rC - rowMeans(rC))^2)))
 c(sqrt(diagonals(Crossprod(solve(L)))))
 
 
 ###################################################
-### code chunk number 74: rC
+### code chunk number 75: rC
 ###################################################
 rC <- ltMatrices(rC, diag = TRUE)
 
 
 ###################################################
-### code chunk number 75: ML-beta
+### code chunk number 76: ML-beta
 ###################################################
 rbeta <- cond_mvnorm(chol = rC, which = 2:J, given = diag(J - 1))$mean
 sqrt(rowMeans((rbeta - rowMeans(rbeta))^2))
 
 
 ###################################################
-### code chunk number 76: se-ex
+### code chunk number 77: se-ex
 ###################################################
 sqrt(diag(vcov(m1)))[-1L]
 
 
 ###################################################
-### code chunk number 77: ex-ML-cd
+### code chunk number 78: ex-ML-cd
 ###################################################
 ic <- 1:2 	### position of continuous variables
 ll_cd <- function(parm, J) {
@@ -1342,7 +1348,7 @@ sc_cd <- function(parm, J) {
 
 
 ###################################################
-### code chunk number 78: ex-ML-cd-score
+### code chunk number 79: ex-ML-cd-score
 ###################################################
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll_cd, start, J = J), sc_cd(start, J = J), 
@@ -1350,11 +1356,11 @@ if (require("numDeriv", quietly = TRUE))
 
 
 ###################################################
-### code chunk number 79: ex-ML-cd-optim
+### code chunk number 80: ex-ML-cd-optim
 ###################################################
 op <- optim(start, fn = ll_cd, gr = sc_cd, J = J, 
             method = "L-BFGS-B", lower = llim, 
-            control = list(trace = TRUE))
+            control = list(trace = FALSE))
 ## estimated C
 ltMatrices(matrix(op$par[-(1:J)], ncol = 1), 
            diag = TRUE, byrow = BYROW)
@@ -1367,7 +1373,7 @@ mn
 
 
 ###################################################
-### code chunk number 80: ex-ML-ap
+### code chunk number 81: ex-ML-ap
 ###################################################
 ### discrete variables first
 perm <- c((1:J)[-ic], ic)
@@ -1384,7 +1390,7 @@ ll_ap <- function(parm, J) {
 
 
 ###################################################
-### code chunk number 81: ex-ML-ap-score
+### code chunk number 82: ex-ML-ap-score
 ###################################################
 sc_ap <- function(parm, J) {
     m <- parm[1:J]               ### mean parameters; NOT permuted
@@ -1405,7 +1411,7 @@ sc_ap <- function(parm, J) {
 
 
 ###################################################
-### code chunk number 82: ex-ML-ap-grad
+### code chunk number 83: ex-ML-ap-grad
 ###################################################
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll_ap, start, J = J), sc_ap(start, J = J), 
@@ -1413,20 +1419,20 @@ if (require("numDeriv", quietly = TRUE))
 
 
 ###################################################
-### code chunk number 83: ex-ML-ap-optim-
+### code chunk number 84: ex-ML-ap-optim-
 ###################################################
 op <- optim(start, fn = ll_ap, gr = sc_ap, J = J, 
             method = "L-BFGS-B", lower = llim, 
-            control = list(trace = TRUE))
+            control = list(trace = FALSE))
 ## estimated C for (X, Y)
 ltMatrices(matrix(op$par[-(1:J)], ncol = 1), 
            diag = TRUE, byrow = BYROW)
 ## compare with true _permuted_ C for (X, Y)
-aperm(as.chol(lt), perm = perm)
+round(as.array(aperm(as.chol(lt), perm = perm)), 4)
 
 
 ###################################################
-### code chunk number 84: ex-stand
+### code chunk number 85: ex-stand
 ###################################################
 C <- ltMatrices(runif(10))
 all.equal(as.array(chol2cov(standardize(chol = C))),
@@ -1437,7 +1443,7 @@ all.equal(as.array(invchol2cov(standardize(invchol = L))),
 
 
 ###################################################
-### code chunk number 85: gc-classical
+### code chunk number 86: gc-classical
 ###################################################
 data("iris", package = "datasets")
 J <- 4
@@ -1458,13 +1464,14 @@ start <- t(chol(CR))
 start <- start[lower.tri(start)]
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll, start), sc(start), check.attributes = FALSE)
-op <- optim(start, fn = ll, gr = sc, method = "BFGS", hessian = TRUE)
+op <- optim(start, fn = ll, gr = sc, method = "BFGS", 
+            control = list(trace = FALSE), hessian = TRUE)
 op$value
 S_ML <- chol2cov(standardize(ltMatrices(op$par)))
 
 
 ###################################################
-### code chunk number 86: gc-NPML
+### code chunk number 87: gc-NPML
 ###################################################
 lwr <- do.call("cbind", lapply(iris[1:J], rank, ties.method = "min")) - 1L
 upr <- do.call("cbind", lapply(iris[1:J], rank, ties.method = "max"))
@@ -1494,19 +1501,20 @@ sc <- function(parm) {
 }
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll, start), sc(start), check.attributes = FALSE)
-op2 <- optim(start, fn = ll, gr = sc, method = "BFGS", hessian = TRUE)
+op2 <- optim(start, fn = ll, gr = sc, method = "BFGS", 
+             control = list(trace = FALSE), hessian = TRUE)
 S_NPML <- chol2cov(standardize(ltMatrices(op2$par)))
 
 
 ###################################################
-### code chunk number 87: gc
+### code chunk number 88: gc
 ###################################################
 S_ML
 S_NPML
 
 
 ###################################################
-### code chunk number 88: gc-se
+### code chunk number 89: gc-se
 ###################################################
 sd_ML <- ltMatrices(sqrt(diag(solve(op$hessian))))
 diagonals(sd_ML) <- 0
@@ -1519,18 +1527,19 @@ if (!inherits(sd_NPML, "try-error")) {
 
 
 ###################################################
-### code chunk number 89: iris-model
+### code chunk number 90: iris-model
 ###################################################
 data("iris", package = "datasets")
 vars <- names(iris)[-5L]
+N <- nrow(iris)
 m <- colMeans(iris[,vars])
-V <- var(iris[,vars])
+V <- var(iris[,vars]) * (N - 1) / N
 iris_mvn <- mvnorm(mean = m, chol = t(chol(V)))
 iris_var <- simulate(iris_mvn, nsim = nrow(iris))
 
 
 ###################################################
-### code chunk number 90: iris-mc
+### code chunk number 91: iris-mc
 ###################################################
 j <- 3:4
 margDist(iris_mvn, which = vars[j])
@@ -1539,19 +1548,19 @@ iris_cmvn <- condDist(iris_mvn, which = vars[j], given = gm)
 
 
 ###################################################
-### code chunk number 91: iris-ll
+### code chunk number 92: iris-ll
 ###################################################
 logLik(object = iris_cmvn, obs = t(iris[,vars[-j]]))
 
 
 ###################################################
-### code chunk number 92: iris-ll-perm
+### code chunk number 93: iris-ll-perm
 ###################################################
 logLik(object = iris_cmvn, obs = t(iris[,rev(vars[-j])]))
 
 
 ###################################################
-### code chunk number 93: iris-lLgrad
+### code chunk number 94: iris-lLgrad
 ###################################################
 J <- length(vars)
 obs <- t(iris[, vars])
@@ -1570,31 +1579,29 @@ sc <- function(parm) {
 
 
 ###################################################
-### code chunk number 94: iris-ML
+### code chunk number 95: iris-ML
 ###################################################
 start <- c(c(iris_mvn$mean), Lower_tri(iris_mvn$scale, diag = TRUE))
-if (require("numDeriv", quietly = TRUE))
-    chk(grad(ll, start), sc(start), check.attributes = FALSE)
+max(abs(sc(start))) < sqrt(.Machine$double.eps)
 op <- optim(start, fn = ll, gr = sc, method = "L-BFGS-B", 
-            lower = llim, control = list(trace = TRUE))
+            lower = llim, control = list(trace = FALSE))
 Chat <- ltMatrices(op$par[-(1:J)], diag = TRUE, names = vars)
 ML <- mvnorm(mean = op$par[1:J], chol = Chat)
 
 
 ###################################################
-### code chunk number 95: iris-ML-hat
+### code chunk number 96: iris-ML-hat
 ###################################################
 ### covariance
-round(chol2cov(ML$scale), 2)
-N <- nrow(iris)
-round(V * (N - 1) / N, 2)
+chol2cov(ML$scale)
+V
 ### mean
 ML$mean[,,drop = TRUE]
 m
 
 
 ###################################################
-### code chunk number 96: iris-interval
+### code chunk number 97: iris-interval
 ###################################################
 v1 <- vars[1]
 q1 <- quantile(iris[[v1]], prob = 1:4 / 5)
@@ -1602,7 +1609,7 @@ head(f1 <- cut(iris[[v1]], breaks = c(-Inf, q1, Inf)))
 
 
 ###################################################
-### code chunk number 97: iris-MLi
+### code chunk number 98: iris-MLi
 ###################################################
 lower <- matrix(c(-Inf, q1)[f1], nrow = 1)
 upper <- matrix(c(q1, Inf)[f1], nrow = 1)
@@ -1611,19 +1618,19 @@ obs <- obs[!rownames(obs) %in% v1,,drop = FALSE]
 if (require("numDeriv", quietly = TRUE))
     chk(grad(ll, start), sc(start), check.attributes = FALSE)
 opi <- optim(start, fn = ll, gr = sc, method = "L-BFGS-B", 
-             lower = llim, control = list(trace = TRUE))
+             lower = llim, control = list(trace = FALSE))
 Chati <- ltMatrices(opi$par[-(1:J)], diag = TRUE, names = vars)
 MLi <- mvnorm(mean = opi$par[1:J], chol = Chati)
 
 
 ###################################################
-### code chunk number 98: iris-MLi-hat
+### code chunk number 99: iris-MLi-hat
 ###################################################
 op$value
 opi$value
 ### covariance
-round(chol2cov(MLi$scale), 2)
-round(chol2cov(ML$scale), 2)
+chol2cov(MLi$scale)
+chol2cov(ML$scale)
 ### mean
 MLi$mean[,,drop = TRUE]
 ML$mean[,,drop = TRUE]
